Package: d3Network
Title: Tools for creating D3 JavaScript network, tree, dendrogram, and
        Sankey graphs from R
Description: This packages is intended to make it easy to create D3 JavaScript
    network, tree, dendrogram, and Sankey graphs from R using data frames.
    !!! NOTE: Active development has moved to the networkD3 package. !!!
Version: 0.5.2.1
Date: 2015-01-31
Author: Christopher Gandrud
Maintainer: Christopher Gandrud <christopher.gandrud@gmail.com>
URL: http://christophergandrud.github.io/d3Network/
BugReports: https://github.com/christophergandrud/d3Network/issues
License: GPL (>= 3)
Depends: R (>= 3.0.0)
Imports: plyr, rjson, whisker
Suggests: RCurl
Packaged: 2015-01-31 12:08:44 UTC; christophergandrud
NeedsCompilation: no
Repository: CRAN
Date/Publication: 2015-01-31 17:29:42
Built: R 4.3.3; ; 2025-01-24 06:20:27 UTC; unix
