#' A data file of nodes from Knuth's Les Miserables characters data base.
#' 
#'  @docType data
#'  @source See Mike Bostock \url{http://bl.ocks.org/mbostock/4062045}.
#'  @keywords datasets
#'  @format A data set with 77 observations of 2 variables. 
#'  @name MisNodes 
#'
NULL

#' A data file of links from Knuth's Les Miserables characters data base.
#' 
#'  @docType data
#'  @source See Mike Bostock \url{http://bl.ocks.org/mbostock/4062045}.
#'  @keywords datasets
#'  @format A data set with 254 observations of 3 variables. 
#'  @name MisLinks 
#'
NULL

#' JSON data file of the Flare class hierarchy.
#'
#' @docType data
#' @source See Mike Bostock \url{http://bl.ocks.org/mbostock/4063550}.
#' @keywords datasets
#' @format A JSON file with two arrays \code{name} and \code{children}.
#' @name flare
#' 
NULL

#' JSON data file of a projection of UK energy production and consumption in 2050.
#'
#' @docType data
#' @source See Mike Bostock \url{http://bost.ocks.org/mike/sankey/}.
#' @keywords datasets
#' @format A JSON file with two arrays \code{nodes} and \code{links}.
#' @name energy
#' 
NULL